@@ -4,7 +4,7 @@ package Yahoo::Marketing::AdEditorialReasons;
 
 use strict; use warnings;
 
-use base qw/Yahoo::Marketing::EditorialReasons/;
+use base qw/Yahoo::Marketing::ComplexType/;
 
 =head1 NAME
 
@@ -14,11 +14,6 @@ Yahoo::Marketing::AdEditorialReasons - an object to represent a Yahoo Marketing
 
 sub _user_setable_attributes {
     return ( qw/ 
-            /  );
-}
-
-sub _read_only_attributes {
-    return ( qw/
                  adEditorialReasons
                  adID
                  descriptionEditorialReasons
@@ -28,6 +23,11 @@ sub _read_only_attributes {
                  urlContentEditorialReasons
                  urlEditorialReasons
                  urlStringEditorialReasons
+            /  );
+}
+
+sub _read_only_attributes {
+    return ( qw/
            / );
 }
 
@@ -39,17 +39,17 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://ysm.techportal.searchmarketing.yahoo.com/docs/reference/dataObjects.asp> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
 
 
-=head2 new
-
-Creates a new instance
-
 =cut
 
 =head1 METHODS
 
+=head2 new
+
+Creates a new instance
+
 =head2 get/set methods
 
 =over 8
